#!/bin/sh

set -e

USAGE="Usage: `basename $0` (get|pull|install|diff|record|revert|push|pushall|send|clean|whatsnew|changes|release) [pkg] .."

[ $# -lt 1 ] && echo $USAGE && exit 1

DIR=$PWD/`dirname $0`
CMD=$1

shift

repos_action () {
    PKG=$1
    echo == $PKG ==
    if [ ! -d "$DIR/../$PKG" -a ! $CMD = 'get' ]; then
	echo "$PKG is missing."
	echo "Please run \"`basename $0` get $PKG\" first."
	exit 1
    fi
    if [ ! $CMD = 'get' ]; then
	cd $DIR/../$PKG
    else
	cd $DIR/..
    fi
    case $CMD in
	clean) cabal clean
	    ;;
	install) cabal install
	    ;;
	diff) darcs diff -u
	    ;;
	get) [ -d "$PKG" ] || darcs get http://patch-tag.com/r/AndyStewart/$PKG
	    ;;
	pull) darcs pull
	    ;;
	push) darcs push AndyStewart@patch-tag.com:/r/AndyStewart/$PKG
	    ;;
	pushall) darcs push AndyStewart@patch-tag.com:/r/AndyStewart/$PKG -a
	    ;;
	record) darcs record -l
	    ;;
	revert) darcs revert
	    ;;
	send) darcs send -O
	    ;;
	whatsnew) darcs whatsnew -s
	    ;;
    changes) darcs changes --last 10
        ;;
    release) rm ./dist/*.tar.gz || cabal sdist && cabal upload ./dist/*.tar.gz
        ;;
	*) echo "Unknown command: $CMD"; echo $USAGE; exit 1
	    ;;
    esac
}

for pkg in ${*:-manatee-core manatee-anything manatee-browser manatee-editor manatee-filemanager manatee-pdfviewer manatee-mplayer manatee-ircclient manatee-processmanager manatee-imageviewer manatee-reader manatee};
do
  repos_action $pkg
done
